
import logging, os, site, tempfile, yaml
from PyQt6.QtCore import Qt
from PyQt6.QtGui import QPalette, QColor

log = logging.getLogger()

def configure(app):
   files = []
   for fname in [ 'icons.yaml', 'actions.yaml', 'menu.yaml', 'config.yaml' ]:
      files += [os.path.join(p, 'tweetypy', fname) for p in site.getsitepackages()]
      if 'XDG_CONFIG_HOME' in os.environ:
         files += [os.path.join(os.environ['XDG_CONFIG_HOME'], 'tweetypy', fname)]
      elif 'HOME' in os.environ:
         files += [os.path.join(os.environ['HOME'], '.config', 'tweetypy', fname)]
      elif 'APPDATA' in os.environ:
         files += os.path.join(os.environ['APPDATA'], 'tweetypy', fname)
      elif 'USERPROFILE' in os.enviorn:
         files += os.path.join(os.environ['USERPROFILE'], 'AppData', 'tweetypy', fname)
      files += [os.path.join(os.getcwd(), fname)]
   log.debug(f'Files: {files}')

   # Color constants
   Window         = app.palette().color(QPalette.ColorRole.Window).name()
   WindowText     = app.palette().color(QPalette.ColorRole.WindowText).name()
   Base           = app.palette().color(QPalette.ColorRole.Base).name()
   AlternateBase  = app.palette().color(QPalette.ColorRole.AlternateBase).name()
   ToolTipBase    = app.palette().color(QPalette.ColorRole.ToolTipBase).name()
   ToolTipText    = app.palette().color(QPalette.ColorRole.ToolTipText).name()
   Text           = app.palette().color(QPalette.ColorRole.Text).name()
   Button         = app.palette().color(QPalette.ColorRole.Button).name()
   ButtonText     = app.palette().color(QPalette.ColorRole.ButtonText).name()
   BrightText     = app.palette().color(QPalette.ColorRole.BrightText).name()
   Highlight      = app.palette().color(QPalette.ColorRole.Highlight).name()
   # Icon style constants
   IconOnly       = Qt.ToolButtonStyle.ToolButtonIconOnly
   TextOnly       = Qt.ToolButtonStyle.ToolButtonTextOnly
   TextBesideIcon = Qt.ToolButtonStyle.ToolButtonTextBesideIcon
   TextUnderIcon  = Qt.ToolButtonStyle.ToolButtonTextUnderIcon
   FollowStyle    = Qt.ToolButtonStyle.ToolButtonFollowStyle
   # Misc constants
   TempFile       = os.path.join(tempfile.gettempdir(), 'tweetypy.log')

   conf = f"""
constants:

   Window: &Window {Window}
   WindowText: &WindowText {WindowText}
   Base: &Base {Base}
   AlternateBase: &AlternateBase {AlternateBase}
   ToolTipBase: &ToolTipBase {ToolTipBase}
   ToolTipText: &ToolTipText {ToolTipText}
   Text: &Text {Text}
   Button: &Button {Button}
   ButtonText: &ButtonText {ButtonText}
   BrightText: &BrightText {BrightText}
   Highlight: &Highlight {Highlight}

   IconOnly: &IconOnly {IconOnly}
   TextOnly: &TextOnly {TextOnly}
   TextBesideIcon: &TextBesideIcon {TextBesideIcon}
   TextUnderIcon: &TextUnderIcon {TextUnderIcon}
   FollowStyle: &FollowStyle {FollowStyle}

   TempFile: &TempFile {TempFile}
"""

   for fname in files:
      if (os.path.isfile(fname)):
         with open(fname, 'r') as fin:
            conf += fin.read()
            log.info(f'Reading config from {fname}')
   return yaml.safe_load(conf)


